function [u,dudx] = lin2pbvpspecgal(sigma,g,N,x)
% Polynomial spectral Galerkin discretization of linear 2nd-order two-point BVP 
% \Blue{$-\frac{d}{dx}(\sigma(x)\frac{du}{dx})=g(x)$}, \Blue{$u(0) = u(1) = 0 $}
% on \Blue{$\Omega = [0,1]$}. Trial space of dimension \Blue{$N$}. 
% Values of approximate solution in points \Blue{$x_j$} are returned in the row vector \texttt{u}
m = N+1;                 % Number of quadrature nodes
[zeta,w] = gaussquad(m); % Obtain Gauss quadrature nodes w.r.t \Blue{$[-1,1]$}
% Compute values of (integrated) Legendre polynomials at Gauss nodes
[V,M] = intlegpol(N+1,zeta'); 
omega = w'.*sigma((zeta'+1)/2)*2;       % Modified quadrature weights
A = V(2:N+1,:)*diag(omega)*V(2:N+1,:)'; % Assemble Galerkin matrix
phi = M*(0.5*w'.*g((zeta'+1)/2))';      % Assemble right hand side vector
mu = A\phi;                             % Solve linear system
% Compute values of integrated Legendre polynomials at output points
[V,M] = intlegpol(N+1,2*x-1);
u = mu'*M;
dudx = mu'*V(2:end-1,:)*2; % 2 is the Jacobian of the linear mapping from [0,1] to [-1,1]

return

